@@ -93,6 +93,8 @@ class ClusterRunner(BaseRunner):
         """
         res = {}
         if not out_of_core:
+            print(df)
+            print(pc_id)
             df3 = merge_cluster_ids(df, pc_id, idx_var)
         else: 
             pc_id.reset_index(inplace=True)
